@@ -209,7 +209,14 @@ gene.plot <- function (x = NULL,
 # fix the dataframe
 MyConds <- data.frame(do.call('rbind', strsplit(as.character(rownames(DATA)),'_',fixed=TRUE)))[1]
 MyConds <- factor(as.matrix(MyConds))
-DATA <- cbind(DATA, Expression = col.legend, Clusters = col.legend.box, Conditions = MyConds)
+
+if (length(col.legend.box) == 0){
+  DATA <- cbind(DATA, Expression = col.legend, Conditions = MyConds)
+}
+if (length(col.legend.box) != 0){
+  DATA <- cbind(DATA, Expression = col.legend, Clusters = col.legend.box, Conditions = MyConds)
+}
+####
 if (!is.null(conds.to.plot)) {
 DATA <- subset(DATA, DATA$Conditions %in% conds.to.plot)
 }
